<?

	/*
	** Check that PHP version 4 is being used.  FreeTrade 2.0
	** uses features available only in PHP4.
	*/
	if(phpversion() < 4.0)
	{
		print("FreeTrade 2.0 requires PHP version 4.0<br>\n");
		exit();
	}


	/*
	** Check for magic quotes being on
	** If magic quotes are on, FreeTrade will not function as
	** expected.  Throughout the site form submissions use
	** addslashes() when submitting to the database, but not
	** when set as the value of a form variables (<INPUT VALUE="...">).
	** This warning is here for people first installing FreeTrade, so
	** once you pass this test, feel free to remove the test.  
	*/
	if(get_magic_quotes_gpc() == 1)
	{
		print("Warning: magic_quotes_gpc needs to be off for FreeTrade to function properly.<BR>\n");
		exit();
	}

	/*
	** Get the name of the server, file path, URI and script name
	*/
	define("SERVER_NAME", $SERVER_NAME);
	define("SCRIPT_NAME", basename(__FILE__));
	define("APPLICATION_ROOT", dirname(dirname(__FILE__)) . "/");
	define("MODULE", APPLICATION_ROOT . "modules/");
	define("EXTERNAL_PATH", dirname($SCRIPT_NAME) . "/");


	/* 
	** set constants
	*/
	if(!include_once(MODULE . "configuration/global"))
	{
		print("Unable to include \"configuration/global\"<br>\n");
		exit();
	}

	/*
	** get library of standard functions
	*/
	if(!include_once(MODULE . "utility/standard_library"))
	{
		print("Unable to include \"standard_library\"<br>\n");
		exit();
	}

	/*
	** perform init code needed with every page view
	*/
	if(!include_once(MODULE . "utility/initialization"))
	{
		print("Unable to include \"initialization\"<br>\n");
		exit();
	}



	/*
	** send headers to cause pages to expire immediately
	**
	** This is important because almost every page contains
	** informatin that should be completely fresh.  Things
	** can get very confusing if a page shows the contents
	** of your basket from ten minutes ago.  Plus, we want
	** to defeat the naughty users who use the back button.
	** At the very least, we'll force them to reload the page.
	*/
	// get the GMT time 
	$timestamp = gmdate("U");

	// build datetime strings 
	$Expires = sprintf("%s %02d %s %04d %02d:%02d:%02d GMT",
		gmdate("D", $timestamp), gmdate("d", $timestamp), 
		gmdate("M", $timestamp), gmdate("Y", $timestamp),
		gmdate("H", $timestamp), gmdate("i", $timestamp), 
		gmdate("s", $timestamp));

	$LastModified = sprintf("%s %02d %s %04d %02d:%02d:%02d GMT",
		gmdate("D"), gmdate("d"), gmdate("M"), gmdate("Y"),
		gmdate("H"), gmdate("i"), gmdate("s"));

	// send headers that should foil proxy servers
	header("Expires: $Expires");
	header("Last-modified: $LastModified");
	header("Cache-Control: no-cache");


	/*
	** Execute action module, if requested.
	** Check for actions that include paths or other suspicious characters.
	*/
	if(isset($ACTION) AND ($ACTION != ""))
	{
		if(eregi('^[A-Z_0-9]*$', $ACTION) AND
			file_exists(MODULE . "action/$ACTION"))
		{
			//try, as much as possible, to disallow actions from being interrupted
			set_time_limit(ACTION_TIME_LIMIT);
			$userAbortOrig = ignore_user_abort(TRUE);
			
			if(!include_once(MODULE . "action/$ACTION"))
			{
				array_push($ActionResults, "\"$ACTION\" failed!");
			}
			
			//restore default settings
			set_time_limit(DEFAULT_TIME_LIMIT);
			ignore_user_abort($userAbortOrig);
		}
		else 
		{
			array_push($ActionResults, "\"$ACTION\" is not a valid action.");
		}
	}

	//no output should be generated above this line because both
	//check_sid and GENERATE_SID send cookies.
	
	/*
	** include array of screen information
	*/
	include_once(MODULE . "configuration/ScreenInfo");

	/*
	** If we aren't given a screen, go home
	*/
	if(!(isset($SCREEN)) OR ($SCREEN==""))
	{
		$SCREEN=DEFAULT_SCREEN;
	}


	/*
	** If screen is bad, go home
	*/
	if(!(file_exists(MODULE . "screen/$SCREEN")) OR 
		(!isset($ScreenInfo[$SCREEN])))
	{
		$SCREEN=DEFAULT_SCREEN;
	}


	/*
	** Start page
	*/
	print('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ');
	print('"http://www.w3.org/TR/html40/loose.dtd">');
	print("\n");
	
	print("<html>\n");
	print("<head>\n");
	print("<title>" . $ScreenInfo[$SCREEN][SI_TITLE] . "</title>\n");


	/*
	** Meta tags
	*/
	print("<meta name=\"description\" content=\"".$ScreenInfo[$SCREEN][SI_DESCRIPTION]."\">\n");
	print("<meta name=\"keywords\" content=\"".$ScreenInfo[$SCREEN][SI_KEYWORDS]."\">\n");
	print("<meta name=\"distribution\" content=\"global\">\n");


	/*
	** styles
	*/
	print("<link rel=\"stylesheet\" href=\"conservatory.css\" ");
	print("type=\"text/css\" media=\"screen\">\n");

	/*
	** Javascript functions
	*/
	if($Browser_JavaScriptOK)
	{
		include_once(MODULE . "utility/popupwindow");
	}

	
	print("</head>\n");

	print("<body bgcolor=\"white\">\n");


	/*
	** go to layout module, that will in turn use navigation and screen modules
	*/
	if(isset($ScreenInfo[$SCREEN][SI_LAYOUT]))
	{
		include_once(MODULE . "layout/".$ScreenInfo[$SCREEN][SI_LAYOUT]);
	}
	else
	{
		include_once(MODULE . "layout/".SI_DEFAULT_LAYOUT);
	}


	/*
	** close page
	*/
	print("</body>\n");
	print("</html>\n");

?>
